# csreuter

<p align="center">
    <a href="https://pypi.python.org/pypi/csreuter/" alt="PyPI version">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/csreuter"></a>
    <a href="https://github.com/EmilRex/csreuter-py/" alt="Stars">
        <img src="https://img.shields.io/github/stars/EmilRex/csreuter-py" /></a>
    <a href="https://pepy.tech/badge/csreuter/" alt="Downloads">
        <img src="https://img.shields.io/pypi/dm/csreuter" /></a>
    <a href="https://github.com/EmilRex/csreuter-py/pulse" alt="Activity">
        <img src="https://img.shields.io/github/commit-activity/m/EmilRex/csreuter-py" /></a>
    <br>
</p>

Python package that likes Maine a little too much.

## Getting Started

```sh
pip install -U csreuter

csreuter --help
```

## Contributing

Unfortunately at this time we only accept contributions from people named Chris.
